@@ -5,12 +5,26 @@ use utf8;
 use Moose;
 use 5.0100;
 
+our $VERSION = $App::iTan::VERSION;
+
 extends qw(MooseX::App::Cmd::Command);
 with qw(App::iTan::Utils);
 
 use Text::Table;
 
-sub run {
+sub execute {
+    my ( $self, $opts, $args ) = @_;
+    
+    my $tb = $self->get_table();
+    
+    print $tb->title;
+    print $tb->rule('-','+');
+    print $tb->body;
+    
+    return;
+}
+
+sub get_table {
     my ($self) = @_;
     
     my $sth = $self->dbh->prepare("SELECT tindex,imported,used,memo FROM itan WHERE valid = 1 OR used IS NOT NULL ORDER BY imported")
@@ -24,20 +38,20 @@ sub run {
     while (my @line = $sth->fetchrow_array) {
         $tb->add(@line);
     }
-
-    print $tb->title;
-    print $tb->rule('-','+');
-    print $tb->body;
     
-    return;
+    return $tb;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 =head1 NAME 
 
 App::iTan::Command::list - List all available and used itans
 
 =head1 DESCRIPTION
 
+See L<App::iTan> for detailed documentation
+
 =cut
 
 1;
\ No newline at end of file
